EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_CreateExecution',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Execution_Id',
    /* Description_Text        */ 'Creates an execution.'
GO

IF OBJECT_ID('[Executions_CreateExecution]') IS NOT NULL DROP PROCEDURE [Executions_CreateExecution]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_CreateExecution]
(
	@ExecutionMode_Code CHAR(1),
	@Start_Date DATETIME = NULL,
	@ExecutionRunState_Code CHAR(1) = NULL,
	@ExecutionType_Name VARCHAR(50) = NULL,
	@Execution_Configuration XML = NULL,
	@Job_Id INT = NULL,
	@Server_Id INT = NULL,
	@Simulation_Indicator YNINDICATOR = NULL,
	@Execution_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	INSERT INTO [Executions]
	(
		[Start_Date],
		[ExecutionStatus_Code],
		[ExecutionRunState_Code],
		[ExecutionMode_Code],
        [ExecutionType_Name],
        [Execution_Configuration],
		[Job_Id],
		[Server_Id],
		[Simulation_Indicator],
		[DriftDetected_Indicator]
	)
	VALUES
	(
		COALESCE(@Start_Date, GETUTCDATE()),
		'S',
		COALESCE(@ExecutionRunState_Code, 'P'),
		@ExecutionMode_Code,
        @ExecutionType_Name,
        @Execution_Configuration,
		@Job_Id,
		@Server_Id,
		COALESCE(@Simulation_Indicator, 'N'),
		'N'
	)

	SET @Execution_Id = SCOPE_IDENTITY()

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Executions_CreateExecution] TO [OtterUser_Role]
