EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Executions_GetLogEntries',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'ScopedExecutionLogEntries',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the latest log entries for a specified execution and log scope.'
GO

IF OBJECT_ID('[Executions_GetLogEntries]') IS NOT NULL DROP PROCEDURE [Executions_GetLogEntries]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Executions_GetLogEntries]
(
	@Execution_Id INT,
    @Scope_Sequence INT,
    @Minimum_Scope_HighestLogEntry_Level INT,
    @IncludeDebug_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

	SELECT *
	  FROM [ScopedExecutionLogEntries] SELE
     INNER JOIN [ScopedExecutionLogs] SEL
             ON SEL.[Execution_Id] = SELE.[Execution_Id]
            AND SEL.[Scope_Sequence] = SELE.[Scope_Sequence]
	 WHERE SELE.[Execution_Id] = @Execution_Id
	   AND (@Scope_Sequence IS NULL OR SELE.[Scope_Sequence] = @Scope_Sequence)
       AND (@Minimum_Scope_HighestLogEntry_Level IS NULL OR SEL.[HighestLogEntry_Level] >= @Minimum_Scope_HighestLogEntry_Level)
	   AND (@IncludeDebug_Indicator = 'Y' OR SELE.[LogEntry_Level] > 0)
	 ORDER BY [LogEntry_Sequence]

END
GO

GRANT EXECUTE ON [Executions_GetLogEntries] TO [OtterUser_Role]
