EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'JobTemplates_CreateOrUpdateJobTemplate',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'JobTemplate_Id',
    /* Description_Text        */ 'Creates a new job template or updates an existing template configuration.'
GO


IF OBJECT_ID('[JobTemplates_CreateOrUpdateJobTemplate]') IS NOT NULL DROP PROCEDURE [JobTemplates_CreateOrUpdateJobTemplate]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [JobTemplates_CreateOrUpdateJobTemplate]
(
	@JobTemplate_Name NVARCHAR(100),
	@JobTemplate_Configuration XML,
    @JobTemplate_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @JobTemplate_Id IS NULL
	BEGIN
		INSERT INTO [JobTemplates]
		(
			[JobTemplate_Name],
			[JobTemplate_Configuration]
		)
		VALUES
		(
			@JobTemplate_Name,
			@JobTemplate_Configuration
		)

		SET @JobTemplate_Id = SCOPE_IDENTITY()
	END
	ELSE
	BEGIN

		UPDATE [JobTemplates]
		   SET [JobTemplate_Name] = @JobTemplate_Name,
			   [JobTemplate_Configuration] = @JobTemplate_Configuration
		 WHERE [JobTemplate_Id] = @JobTemplate_Id

	END

   COMMIT
END TRY BEGIN CATCH
   IF XACT_STATE()<>0 ROLLBACK
   EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [JobTemplates_CreateOrUpdateJobTemplate] TO [OtterUser_Role]
