EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Security_AddPrivilege',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Privilege_Id',
    /* Description_Text        */ 'Grants or denies the specified principal the ability to perform a certain role'
GO

IF OBJECT_ID('[Security_AddPrivilege]') IS NOT NULL
    DROP PROCEDURE [Security_AddPrivilege]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Security_AddPrivilege]
(
    @Privilege_Id INT = NULL OUT,
    @UserDirectory_Id INT,
    @Principal_Name USERNAME,
    @PrincipalType_Code CHAR(1),
    @Role_Id INT,
    @Environment_Id INT,
    @PrivilegeType_Code CHAR(1)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
    BEGIN TRANSACTION

    IF @Environment_Id IS NOT NULL AND EXISTS(SELECT * FROM [Roles] WHERE [Role_Id] = @Role_Id AND [EnvironmentScopable_Indicator] = 'N')
       SET @Environment_Id = NULL

    /* Catch duplicate data */
    IF EXISTS(SELECT *
                FROM [Privileges]
               WHERE [Principal_Name] = @Principal_Name
                 AND [UserDirectory_Id] = @UserDirectory_Id
                 AND [PrincipalType_Code] = @PrincipalType_Code
                 AND [Role_Id] = @Role_Id
                 AND ((@Environment_Id IS NOT NULL AND [Environment_Id] = @Environment_Id)
                      OR 
                      (@Environment_Id IS NULL AND [Environment_Id] IS NULL))
                 AND [PrivilegeType_Code] = @PrivilegeType_Code )
    BEGIN
        ROLLBACK
        RETURN
    END

    INSERT INTO [Privileges]
        ([UserDirectory_Id]
        ,[Principal_Name]
        ,[PrincipalType_Code]
        ,[Role_Id]
        ,[Environment_Id]
        ,[PrivilegeType_Code])
    VALUES
        (@UserDirectory_Id
        ,@Principal_Name
        ,@PrincipalType_Code
        ,@Role_Id
        ,@Environment_Id
        ,@PrivilegeType_Code)
    SET @Privilege_Id = SCOPE_IDENTITY()

    -- EXEC [Events_RaiseEvent] 'SECNWP', NULL, @Privilege_Id

    COMMIT
END TRY BEGIN CATCH
    IF XACT_STATE()<>0 ROLLBACK
    EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Security_AddPrivilege] TO [OtterUser_Role]
GO
